@@ -6,21 +6,28 @@ use Test2::V0;
 
 use Future;
 
+my $__dummy; # to defeat non-closure optimsation
+
 # then done
 {
    my $f1 = Future->new;
 
+   my ( $cbt, $cbe );
    my $fdone;
    my $fseq = $f1->then(
-      sub {
+      $cbt = sub {
          is( $_[0], "f1 result", '2-arg then done block passed result of $f1' );
          return $fdone = Future->new;
       },
-      sub {
+      $cbe = sub {
+         $__dummy++;
          die "then fail block should not be invoked";
       },
    );
 
+   is_refcount( $cbt, 2, '$cbt has refcount 2 captured by then callback' );
+   is_refcount( $cbe, 2, '$cbe has refcount 2 captured by then callback' );
+
    $f1->done( "f1 result" );
 
    ok( defined $fdone, '$fdone now defined after $f1 done' );
@@ -29,6 +36,9 @@ use Future;
 
    ok( $fseq->is_ready, '$fseq is done after $fdone done' );
    is( [ $fseq->result ], [ results => "here" ], '$fseq->result returns results' );
+
+   is_oneref( $cbt, '$cbt has refcount 1 at EOF' );
+   is_oneref( $cbe, '$cbe has refcount 1 at EOF' );
 }
 
 # then fail
@@ -56,6 +66,29 @@ use Future;
    is( [ $fseq->result ], [ fallback => "result" ], '$fseq->result returns results' );
 }
 
+# then done immediate
+{
+   my $f1 = Future->done;
+
+   my ( $cbt, $cbe );
+   my $fdone;
+   my $fseq = $f1->then(
+      $cbt = sub { return $fdone = Future->new },
+      $cbe = sub {
+         $__dummy++;
+         die "then fail block should not be invoked";
+      },
+   );
+
+   $fdone->done( results => "here" );
+
+   ok( $fseq->is_ready, '$fseq is done after $fdone done' );
+   is( [ $fseq->result ], [ results => "here" ], '$fseq->result returns results' );
+
+   is_oneref( $cbt, '$cbt has refcount 1 at EOF' );
+   is_oneref( $cbe, '$cbe has refcount 1 at EOF' );
+}
+
 # then done fails doesn't trigger fail block
 {
    my $f1 = Future->new;
